/*
 * testerWindow.js
 *
 * Test Manager
 * Add bookmark
 * Remove bookmark
 * Add folder
 * Delete folder
 * Bookmark all tabs
 */

var suite = {
    testManager: function() {
        try {
            assertNotUndefined(testerWindow.bookmarksManager);
            testerWindow.passTest("test manager");
        } catch (e) {
            testerWindow.failTest("test manager");
        }
    },

    testAddBookmark: function() {
        var res = testerWindow.bookmarksManager.createBookmark("mozilla.org", "http://www.mozilla.org/", null, "Mozilla Foundation", "iso-8859-1");

        try {
            // deprecated test function. Need to find a better one.
            assert(testerWindow.bookmarksManager.isBookmarkedResource("http://www.mozilla.org/"));
            testerWindow.passTest("add bookmark");
        } catch (e) {
            testerWindow.failTest("add bookmark");
        }
    },

    testRemoveBookmark: function() {
        // stub
    },

    testAddFolder: function() {
        // stub
    },

    testDeleteFolder: function() {
        // stubby
    },

    testBookmarkAllTabs: function() {
        // stub stub
    },
};

function countTests() {
    var totalTests = 0;
    for (each in suite) {
        if (each.slice(0, 4) == "test") { totalTests++ };
    }

    return totalTests;
}

function BookmarksTests() {
    logText("initializing bookmarksTests");
    this.browserWindow = window.opener;
    this.bookmarksManager = Components.classes["@mozilla.org/browser/bookmarks-service;1"].getService(Components.interfaces.nsIBookmarksService);
    this.totalTests = countTests();
    logText("finished initializing bookmarksTests");
}

var testerWindow = {
    pass: true,

    startup: function() {
        logText("testerWindow startup");
        this.bookmarksTests = new BookmarksTests();
        this.testsRun = new Array();
        logText("finished startup");
    },

    // window update messages

    resetProgressMeter: function() {
        setNumberOfTests(0);
        setProgressMeter(0);
    },

    incrementProgressMeter: function() {
        var tests = this.testsRun.length;
        setNumberOfTests(tests);
        setProgressMeter(Math.round(tests / this.bookmarksTests.totalTests * 100));
    },

    passTest: function(test) {
        logText("passing test " + test);
        this.testsRun.push(test);
        this.incrementProgressMeter();
        this.setPass();
    },

    failTest: function(test) {
        logText("failing test " + test);
        this.testsRun.push(test);
        this.incrementProgressMeter();
        this.setFail();
    },

    setPass: function() {
        this.pass = this.pass && true;
    },

    setFail: function() {
        this.pass = false;
    },
};

function runTests() {
    logText("run tests pushed");

    setStatusMessage("Running...");

    logText("totalTests = " + testerWindow.bookmarksTests.totalTests);

    try {
        setTotalTests(testerWindow.bookmarksTests.totalTests);
        for (test in suite) {
            if (test.slice(0,4) != "test") { continue; }
            logText("running test " + test);
            suite[test].call();
        }
    } catch(e) {
        setStatusMessage("Exception caught. Failed!");
        logText("exception: " + e);
    }
}

window.addEventListener("load", testerWindow.startup(), false);